/**
 * Colors
 */
/**
 * SCSS Variables.
 *
 * Please use variables from this sheet to ensure consistency across the UI.
 * Don't add to this sheet unless you're pretty sure the value will be reused in many places.
 * For example, don't add rules to this sheet that affect block visuals. It's purely for UI.
 */
/**
 * Fonts & basic variables.
 */
/**
 * Typography
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Radius scale.
 */
/**
 * Elevation scale.
 */
/**
 * Dimensions.
 */
/**
 * Mobile specific styles
 */
/**
 * Editor styles.
 */
/**
 * Block & Editor UI.
 */
/**
 * Block paddings.
 */
/**
 * React Native specific.
 * These variables do not appear to be used anywhere else.
 */
.block-editor-block-list__block[data-type="core/spacer"]::before {
  content: "";
  display: block;
  position: absolute;
  z-index: 1;
  width: 100%;
  min-height: 8px;
  min-width: 8px;
  height: 100%;
}

.wp-block-spacer.is-hovered .block-library-spacer__resize-container,
.block-library-spacer__resize-container.has-show-handle,
.wp-block-spacer.is-selected.custom-sizes-disabled {
  background: rgba(0, 0, 0, 0.1);
}
.is-dark-theme .wp-block-spacer.is-hovered .block-library-spacer__resize-container,
.is-dark-theme .block-library-spacer__resize-container.has-show-handle,
.is-dark-theme .wp-block-spacer.is-selected.custom-sizes-disabled {
  background: rgba(255, 255, 255, 0.15);
}

.block-library-spacer__resize-container {
  clear: both;
}
.block-library-spacer__resize-container:not(.is-resizing) {
  height: 100% !important;
  width: 100% !important;
}
.block-library-spacer__resize-container .components-resizable-box__handle::before {
  content: none;
}
.block-library-spacer__resize-container.resize-horizontal {
  margin-bottom: 0;
  height: 100% !important;
}